==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/is.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
    "Storage invalid" : "Ógild geymsla",
    "Unknown error" : "Óþekkt villa",
    "All files" : "Allar skrár",
    "Recent" : "Nýlegt",
    "File could not be found" : "Skrá finnst ekki",
    "Home" : "Heim",
    "Close" : "Loka",
    "Favorites" : "Eftirlæti",
    "Could not create folder \"{dir}\"" : "Gat ekki búið til möppuna \"{dir}\"",
    "Upload cancelled." : "Hætt við innsendingu.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Tókst ekki að hlaða inn {filename} þar sem þetta er mappa eða er 0 bæti",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ekki nægilegt laust pláss, þú ert að senda inn {size1} en einungis {size2} eru eftir",
    "Target folder \"{dir}\" does not exist any more" : "Markmappan \"{dir}\" er ekki lengur til",
    "Not enough free space" : "Ekki nægilegt pláss",
    "Uploading..." : "Sendi inn ...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
    "Actions" : "Aðgerðir",
    "Download" : "Niðurhal",
    "Rename" : "Endurnefna",
    "Move" : "Færa",
    "Target folder" : "Markmappa",
    "Delete" : "Eyða",
    "Disconnect storage" : "Aftengja geymslu",
    "Unshare" : "Hætta deilingu",
    "Could not load info for file \"{file}\"" : "Gat ekki lesið upplýsingar um skrána \"{file}\"",
    "Files" : "Skrár",
    "Details" : "Nánar",
    "Select" : "Velja",
    "Pending" : "Í bið",
    "Unable to determine date" : "Tókst ekki að ákvarða dagsetningu",
    "This operation is forbidden" : "Þessi aðgerð er bönnuð",
    "This directory is unavailable, please check the logs or contact the administrator" : "Þessi mappa er ekki tiltæk, athugaðu annálana eða hafðu samband við kerfissjóra",
    "Could not move \"{file}\", target exists" : "Gat ekki fært \"{file}\", markskrá er til",
    "Could not move \"{file}\"" : "Gat ekki fært \"{file}\"",
    "{newName} already exists" : "{newName} er þegar til",
    "Could not rename \"{fileName}\", it does not exist any more" : "Gat ekki endurnefnt \"{fileName}\", það er ekki lengur til staðar",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Heitið \"{targetName}\" er nú þegar notað í \"{dir}\" möppunni. Veldu eitthvað annað nafn.",
    "Could not rename \"{fileName}\"" : "Gat ekki endurnefnt \"{fileName}\"",
    "Could not create file \"{file}\"" : "Gat ekki búið til skrána \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Gat ekki búið til skrána \"{file}\" vegna þess að hún er þegar til",
    "Could not create folder \"{dir}\" because it already exists" : "Gat ekki búið til möppuna \"{dir}\" vegna þess að hún er þegar til",
    "Error deleting file \"{fileName}\"." : "Villa við að eyða skránni \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Engar leitarniðurstöður í öðrum möppum fyrir {tag}{filter}{endtag}",
    "Name" : "Heiti",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "_%n folder_::_%n folders_" : ["%n mappa","%n möppur"],
    "_%n file_::_%n files_" : ["%n skrá","%n skrár"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["þar á meðal %n falin","þar á meðal %n faldar"],
    "You don’t have permission to upload or create files here" : "Þú hefur ekki heimild til að hlaða inn eða búa til skjöl hér",
    "_Uploading %n file_::_Uploading %n files_" : ["Sendi inn %n skrá","Sendi inn %n skrár"],
    "New" : "Nýtt",
    "\"{name}\" is an invalid file name." : "\"{name}\" er ógilt skráarheiti.",
    "File name cannot be empty." : "Heiti skráar má ekki vera tómt",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ógild skráartegund",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Geymslupláss {owner} er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Your storage is full, files can not be updated or synced anymore!" : "Geymsluplássið þitt er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Geymslupláss {owner} er næstum fullt ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Geymsluplássið þitt er næstum fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["samsvarar '{filter}'","samsvara '{filter}'"],
    "View in folder" : "Skoða í möppu",
    "Path" : "Slóð",
    "_%n byte_::_%n bytes_" : ["%n bæti","%n bæti"],
    "Favorited" : "Sett í eftirlæti",
    "Favorite" : "Eftirlæti",
    "Folder" : "Mappa",
    "New folder" : "Ný mappa",
    "Upload" : "Senda inn",
    "An error occurred while trying to update the tags" : "Villa kom upp við að reyna að uppfæra merkin",
    "Added to favorites" : "Bætt í eftirlæti",
    "Removed from favorites" : "Fjarlægt úr eftirlætum",
    "You added {file} to your favorites" : "Þú bættir {file} í eftirlætin þín",
    "You removed {file} from your favorites" : "Þú fjarlægðir {file} úr eftirlætunum þínum",
    "File changes" : "Skráarbreytingar",
    "Created by {user}" : "Búið til af {user}",
    "Changed by {user}" : "Breytt af {user}",
    "Deleted by {user}" : "Eytt af {user}",
    "Restored by {user}" : "Endurheimt af {user}",
    "Renamed by {user}" : "Endurnefnt af {user}",
    "Moved by {user}" : "Fært af {user}",
    "You created {file}" : "Þú bjóst til {file}",
    "{user} created {file}" : "{user} bjó til {file}",
    "{file} was created in a public folder" : "{file} var búin til í opinni möppu",
    "You changed {file}" : "Þú breyttir {file}",
    "{user} changed {file}" : "{user} breytti {file}",
    "You deleted {file}" : "Þú eyddir {file}",
    "{user} deleted {file}" : "{user} eyddi {file}",
    "You restored {file}" : "Þú endurheimtir {file}",
    "{user} restored {file}" : "{user} endurheimti {file}",
    "You renamed {oldfile} to {newfile}" : "Þú endurnefndir {oldfile} sem {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} endurnefndi {oldfile} sem {newfile}",
    "You moved {oldfile} to {newfile}" : "Þú færðir {oldfile} í {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} færði {oldfile} í {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Skrá var bætt við eða hún fjarlægð úr <strong>eftirlætum</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Skrá eða möppu hefur verið <strong>breytt</strong> eða verið <strong>endurnefnt</strong>",
    "A new file or folder has been <strong>created</strong>" : "Skjal eða mappa hefur verið <strong>búin til</strong>",
    "A new file or folder has been <strong>deleted</strong>" : "Nýrri skrá eða möppu hefur verið  <strong>eytt</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Takmarka tilkynningar um gerð og breytingar á <strong>eftirlætisskrám</strong> <em>(einungis streymi)</em>",
    "A new file or folder has been <strong>restored</strong>" : "Ný skrá eða mappa hefur verið <strong>endurheimt</strong>",
    "Upload (max. %s)" : "Senda inn (hám. %s)",
    "File handling" : "Meðhöndlun skráar",
    "Maximum upload size" : "Hámarksstærð innsendingar",
    "max. possible: " : "hámark mögulegt: ",
    "Save" : "Vista",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Með PHP-FPM getur það tekið 5 mínútur fyrir breytingar að verða virkar.",
    "Missing permissions to edit from here." : "Vantar heimildir til að breyta einhverju héðan.",
    "Settings" : "Stillingar",
    "Show hidden files" : "Sýna faldar skrár",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Notaðu þetta vistfang til að <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">nálgast skrárnar þínar með WebDAV</a>",
    "No files in here" : "Engar skrár hér",
    "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Select all" : "Velja allt",
    "Upload too large" : "Innsend skrá er of stór",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
    "Files and folders you mark as favorite will show up here" : "Skrár og möppur sem þú merkir sem eftirlæti birtast hér",
    "Shared with you" : "Deilt með þér",
    "Shared with others" : "Deilt með öðrum",
    "Shared by link" : "Deilt með tengli",
    "Tags" : "Merki",
    "Deleted files" : "Eyddar skrár",
    "Text file" : "Textaskrá",
    "New text file.txt" : "Ný textaskrá.txt",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["{hours}:{minutes}:{seconds} klukkustund eftir","{hours}:{minutes}:{seconds} klukkustundir eftir"],
    "{hours}:{minutes}h" : "{hours}:{minutes}klst",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["{minutes}:{seconds} mínúta eftir","{minutes}:{seconds} mínútur eftir"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}mín",
    "_{seconds} second left_::_{seconds} seconds left_" : ["{seconds} sekúnda eftir","{seconds} sekúndur eftir"],
    "{seconds}s" : "{seconds}sek",
    "Any moment now..." : "Á hverri stundu...",
    "Soon..." : "Bráðum...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Innsending í gangi. Ef þú ferð af þessari síðu mun innsending hætta.",
    "Copy local link" : "Afrita staðværan tengil",
    "No favorites" : "Engin eftirlæti"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/is.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
    "Storage invalid" : "Ógild geymsla",
    "Unknown error" : "Óþekkt villa",
    "All files" : "Allar skrár",
    "Recent" : "Nýlegt",
    "File could not be found" : "Skrá finnst ekki",
    "Home" : "Heim",
    "Close" : "Loka",
    "Favorites" : "Eftirlæti",
    "Could not create folder \"{dir}\"" : "Gat ekki búið til möppuna \"{dir}\"",
    "Upload cancelled." : "Hætt við innsendingu.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Tókst ekki að hlaða inn {filename} þar sem þetta er mappa eða er 0 bæti",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ekki nægilegt laust pláss, þú ert að senda inn {size1} en einungis {size2} eru eftir",
    "Target folder \"{dir}\" does not exist any more" : "Markmappan \"{dir}\" er ekki lengur til",
    "Not enough free space" : "Ekki nægilegt pláss",
    "Uploading..." : "Sendi inn ...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
    "Actions" : "Aðgerðir",
    "Download" : "Niðurhal",
    "Rename" : "Endurnefna",
    "Move" : "Færa",
    "Target folder" : "Markmappa",
    "Delete" : "Eyða",
    "Disconnect storage" : "Aftengja geymslu",
    "Unshare" : "Hætta deilingu",
    "Could not load info for file \"{file}\"" : "Gat ekki lesið upplýsingar um skrána \"{file}\"",
    "Files" : "Skrár",
    "Details" : "Nánar",
    "Select" : "Velja",
    "Pending" : "Í bið",
    "Unable to determine date" : "Tókst ekki að ákvarða dagsetningu",
    "This operation is forbidden" : "Þessi aðgerð er bönnuð",
    "This directory is unavailable, please check the logs or contact the administrator" : "Þessi mappa er ekki tiltæk, athugaðu annálana eða hafðu samband við kerfissjóra",
    "Could not move \"{file}\", target exists" : "Gat ekki fært \"{file}\", markskrá er til",
    "Could not move \"{file}\"" : "Gat ekki fært \"{file}\"",
    "{newName} already exists" : "{newName} er þegar til",
    "Could not rename \"{fileName}\", it does not exist any more" : "Gat ekki endurnefnt \"{fileName}\", það er ekki lengur til staðar",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Heitið \"{targetName}\" er nú þegar notað í \"{dir}\" möppunni. Veldu eitthvað annað nafn.",
    "Could not rename \"{fileName}\"" : "Gat ekki endurnefnt \"{fileName}\"",
    "Could not create file \"{file}\"" : "Gat ekki búið til skrána \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Gat ekki búið til skrána \"{file}\" vegna þess að hún er þegar til",
    "Could not create folder \"{dir}\" because it already exists" : "Gat ekki búið til möppuna \"{dir}\" vegna þess að hún er þegar til",
    "Error deleting file \"{fileName}\"." : "Villa við að eyða skránni \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Engar leitarniðurstöður í öðrum möppum fyrir {tag}{filter}{endtag}",
    "Name" : "Heiti",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "_%n folder_::_%n folders_" : ["%n mappa","%n möppur"],
    "_%n file_::_%n files_" : ["%n skrá","%n skrár"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["þar á meðal %n falin","þar á meðal %n faldar"],
    "You don’t have permission to upload or create files here" : "Þú hefur ekki heimild til að hlaða inn eða búa til skjöl hér",
    "_Uploading %n file_::_Uploading %n files_" : ["Sendi inn %n skrá","Sendi inn %n skrár"],
    "New" : "Nýtt",
    "\"{name}\" is an invalid file name." : "\"{name}\" er ógilt skráarheiti.",
    "File name cannot be empty." : "Heiti skráar má ekki vera tómt",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ógild skráartegund",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Geymslupláss {owner} er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Your storage is full, files can not be updated or synced anymore!" : "Geymsluplássið þitt er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Geymslupláss {owner} er næstum fullt ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Geymsluplássið þitt er næstum fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["samsvarar '{filter}'","samsvara '{filter}'"],
    "View in folder" : "Skoða í möppu",
    "Path" : "Slóð",
    "_%n byte_::_%n bytes_" : ["%n bæti","%n bæti"],
    "Favorited" : "Sett í eftirlæti",
    "Favorite" : "Eftirlæti",
    "Copy direct link (only works for users who have access to this file/folder)" : "Afrita beinan tengil (virkar bara fyrir notendur sem eiga aðgang að þessari skrá/möppu)",
    "New folder" : "Ný mappa",
    "Upload file" : "Senda inn skrá",
    "An error occurred while trying to update the tags" : "Villa kom upp við að reyna að uppfæra merkin",
    "Added to favorites" : "Bætt í eftirlæti",
    "Removed from favorites" : "Fjarlægt úr eftirlætum",
    "You added {file} to your favorites" : "Þú bættir {file} í eftirlætin þín",
    "You removed {file} from your favorites" : "Þú fjarlægðir {file} úr eftirlætunum þínum",
    "File changes" : "Skráarbreytingar",
    "Created by {user}" : "Búið til af {user}",
    "Changed by {user}" : "Breytt af {user}",
    "Deleted by {user}" : "Eytt af {user}",
    "Restored by {user}" : "Endurheimt af {user}",
    "Renamed by {user}" : "Endurnefnt af {user}",
    "Moved by {user}" : "Fært af {user}",
    "You created {file}" : "Þú bjóst til {file}",
    "{user} created {file}" : "{user} bjó til {file}",
    "{file} was created in a public folder" : "{file} var búin til í opinni möppu",
    "You changed {file}" : "Þú breyttir {file}",
    "{user} changed {file}" : "{user} breytti {file}",
    "You deleted {file}" : "Þú eyddir {file}",
    "{user} deleted {file}" : "{user} eyddi {file}",
    "You restored {file}" : "Þú endurheimtir {file}",
    "{user} restored {file}" : "{user} endurheimti {file}",
    "You renamed {oldfile} to {newfile}" : "Þú endurnefndir {oldfile} sem {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} endurnefndi {oldfile} sem {newfile}",
    "You moved {oldfile} to {newfile}" : "Þú færðir {oldfile} í {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} færði {oldfile} í {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Skrá var bætt við eða hún fjarlægð úr <strong>eftirlætum</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Skrá eða möppu hefur verið <strong>breytt</strong> eða verið <strong>endurnefnt</strong>",
    "A new file or folder has been <strong>created</strong>" : "Skjal eða mappa hefur verið <strong>búin til</strong>",
    "A new file or folder has been <strong>deleted</strong>" : "Nýrri skrá eða möppu hefur verið  <strong>eytt</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Takmarka tilkynningar um gerð og breytingar á <strong>eftirlætisskrám</strong> <em>(einungis streymi)</em>",
    "A new file or folder has been <strong>restored</strong>" : "Ný skrá eða mappa hefur verið <strong>endurheimt</strong>",
    "Upload (max. %s)" : "Senda inn (hám. %s)",
    "File handling" : "Meðhöndlun skráar",
    "Maximum upload size" : "Hámarksstærð innsendingar",
    "max. possible: " : "hámark mögulegt: ",
    "Save" : "Vista",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Með PHP-FPM getur það tekið 5 mínútur fyrir breytingar að verða virkar.",
    "Missing permissions to edit from here." : "Vantar heimildir til að breyta einhverju héðan.",
    "Settings" : "Stillingar",
    "Show hidden files" : "Sýna faldar skrár",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Notaðu þetta vistfang til að <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">nálgast skrárnar þínar með WebDAV</a>",
    "No files in here" : "Engar skrár hér",
    "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Select all" : "Velja allt",
    "Upload too large" : "Innsend skrá er of stór",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
    "No favorites yet" : "Engin eftirlæti ennþá",
    "Files and folders you mark as favorite will show up here" : "Skrár og möppur sem þú merkir sem eftirlæti birtast hér",
    "Shared with you" : "Deilt með þér",
    "Shared with others" : "Deilt með öðrum",
    "Shared by link" : "Deilt með tengli",
    "Tags" : "Merki",
    "Deleted files" : "Eyddar skrár",
    "Text file" : "Textaskrá",
    "New text file.txt" : "Ný textaskrá.txt",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["{hours}:{minutes}:{seconds} klukkustund eftir","{hours}:{minutes}:{seconds} klukkustundir eftir"],
    "{hours}:{minutes}h" : "{hours}:{minutes}klst",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["{minutes}:{seconds} mínúta eftir","{minutes}:{seconds} mínútur eftir"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}mín",
    "_{seconds} second left_::_{seconds} seconds left_" : ["{seconds} sekúnda eftir","{seconds} sekúndur eftir"],
    "{seconds}s" : "{seconds}sek",
    "Any moment now..." : "Á hverri stundu...",
    "Soon..." : "Bráðum...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Innsending í gangi. Ef þú ferð af þessari síðu mun innsending hætta.",
    "Copy local link" : "Afrita staðværan tengil",
    "Folder" : "Mappa",
    "Upload" : "Senda inn",
    "No favorites" : "Engin eftirlæti"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
